@@ -57,7 +57,7 @@ def format_html(text):
     email=re.compile('"([\w\-\.]+@[\w\-\.]+)"')
     result=email.sub(r'<A HREF="mailto:\1">\1</A>',result);
 
-    url=re.compile('"http://([\w\-\.]+)"', re.I)
+    url=re.compile('"http://([\w\-\./]+)"', re.I)
     result=url.sub(r'<A HREF="http://\1">\1</A>',result);
     
     return result
@@ -149,9 +149,12 @@ class XMLToHTML(XMLToX):
         self.header=header
         self.footer=footer
     def start_file(self,title):
-        self.write("<HTML><BODY><HEAD><TITLE>"+\
+        self.write("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 3.2//EN\">\n"+\
+                   "<HTML>\n<HEAD>\n"+\
+                   "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\n"+\
+                   "<TITLE>"+\
                    title+\
-                   "</TITLE></HEAD><BODY>\n"+\
+                   "</TITLE>\n</HEAD>\n<BODY>\n\n"+\
                    self.header+\
                    "\n<CENTER><H1>"+\
                    title+\
@@ -174,7 +177,7 @@ class XMLToHTML(XMLToX):
         self.write("<PRE>")
     def end_file(self):
         self.write(self.footer+\
-                   "\n</BODY></HTML>")
+                   "\n</BODY>\n</HTML>\n")
     def end_chap(self):
         self.write("\n")
     def end_part(self):
@@ -386,6 +389,48 @@ class XMLToTxt(XMLToX):
                 result=" "*(self.indent-2)+"* "+result[self.indent:]
         return result
 
+class XMLToTexi(XMLToX):
+    def __init__(self,node):
+        XMLToX.__init__(self)
+        self.node=node
+    def start_file(self,title):
+        self.write("\n@node "+self.node+" , , , Top\n")
+        self.write("\n@chapter "+title+"\n");
+    def start_chap(self,title):
+        self.write("\n@section "+title+"\n");
+    def start_part(self,title):
+        self.write("\n@subsection "+title+"\n");
+    def start_text(self):
+        self.write("\n")
+    def start_list(self):
+        self.write("\n@itemize @bullet")
+    def start_elem(self):
+        self.write("\n@item\n")
+    def start_code(self):
+        self.write("\n@example\n")
+    def end_file(self):
+        self.write("\n")
+    def end_chap(self):
+        self.write("\n")
+    def end_part(self):
+        self.write("\n")
+    def end_text(self):
+        self.write("\n")
+    def end_list(self):
+        self.write("@end itemize\n")
+    def end_elem(self):
+        self.write("\n")
+    def end_code(self):
+        self.write("\n@end example\n")
+    def translate(self,data,tag):
+        result=data
+
+        if (tag!="CODE"):
+            result=remove_duplicate_blanks(result);
+        result=string.replace(result,"@","@@")
+
+        return result
+
 def run_parser(parser,dst,src):
     dst_file=open(dst,"w")
     src_file=open(src,"r")
@@ -422,6 +467,12 @@ def make_txt(txt,xml,header):
     parser=XMLToTxt(header)
     run_parser(parser,txt,xml)
 
+def make_texi(texi,xml):
+    node=string.replace(xml,".xml","")
+    node=string.replace(node,"xml/","")
+    parser=XMLToTexi(node)
+    run_parser(parser,texi,xml)
+
 
 
 
