@@ -20,9 +20,27 @@
 /*                                                                  */
 /********************************************************************/
 
-/********************************************************************/
-/* this software is protected by the GPL, see copying.txt           */
-/********************************************************************/
+/*****************************************************************************/
+/* Liquid War is a unique multiplayer wargame                                */
+/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/*                                                                           */
+/* This program is free software; you can redistribute it and/or modify      */
+/* it under the terms of the GNU General Public License as published by      */
+/* the Free Software Foundation; either version 2 of the License, or         */
+/* (at your option) any later version.                                       */
+/*                                                                           */
+/* This program is distributed in the hope that it will be useful,           */
+/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
+/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
+/* GNU General Public License for more details.                              */
+/*                                                                           */
+/* You should have received a copy of the GNU General Public License         */
+/* along with this program; if not, write to the Free Software               */
+/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/*                                                                           */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Contact author      : ufoot@ufoot.org                                     */
+/*****************************************************************************/
 
 /********************************************************************/
 /* name          : basicopt.c                                       */
@@ -38,6 +56,7 @@
 #include <string.h>
 
 #include "base.h"
+#include "basicopt.h"
 #include "log.h"
 #include "parser.h"
 #include "sockgen.h"
@@ -70,6 +89,25 @@ int lw_basicopt_process(char *name)
   if (exist_argument("h") || exist_argument("?"))
     {
       result=0;
+      lw_basicopt_legal_info(name);
+      log_println();
+      log_println_str("Documentation is available in HTML, ascii text, PostScript, PDF... Read it 8-)");
+    }
+
+  /*
+   * "-netlog" forces the socket messages to be traced
+   */
+  if (exist_argument("netlog"))
+    {
+      LW_SOCK_LOG=1;
+    }
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+void lw_basicopt_legal_info(char *name)
+{
       log_println();
       log_println_str(name);
       log_println();
@@ -92,20 +130,6 @@ int lw_basicopt_process(char *name)
       log_println_str("along with this program; if not, write to the Free Software");
       log_println_str("Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA");
       log_println();
-      log_println_str("Documentation is available in HTML, ascii text, PostScript, PDF... Read it 8-)");
-      log_println();
       log_println_str("Liquid War homepage : http://www.ufoot.org/liquidwar");
       log_println_str("Contact author      : ufoot@ufoot.org");
-    }
-
-  /*
-   * "-netlog" forces the socket messages to be traced
-   */
-  if (exist_argument("netlog"))
-    {
-      LW_SOCK_LOG=1;
-    }
-
-  return result;
 }
-
