@@ -89,6 +89,7 @@
 #define LABEL_CLICK_VOLUME "CLICK_VOLUME"
 #define LABEL_WATER_VOLUME_MENU "WATER_VOLUME_MENU"
 #define LABEL_WATER_VOLUME_GAME "WATER_VOLUME_GAME"
+#define LABEL_MUSIC_VOLUME "MUSIC_VOLUME"
 #define LABEL_LEVEL_MAP "LEVEL_MAP"
 #define LABEL_LEVEL_FG "LEVEL_FG"
 #define LABEL_LEVEL_BG "LEVEL_BG"
@@ -130,6 +131,7 @@ int CONFIG_SFX_VOLUME;
 int CONFIG_CLICK_VOLUME;
 int CONFIG_WATER_VOLUME_MENU;
 int CONFIG_WATER_VOLUME_GAME;
+int CONFIG_MUSIC_VOLUME;
 int CONFIG_LEVEL_MAP;
 int CONFIG_LEVEL_FG;
 int CONFIG_LEVEL_BG;
@@ -203,8 +205,9 @@ void load_default_options (void)
  CONFIG_NUMBER_INFLUENCE=8;
  CONFIG_SFX_VOLUME=12;
  CONFIG_CLICK_VOLUME=8;
- CONFIG_WATER_VOLUME_MENU=4;
- CONFIG_WATER_VOLUME_GAME=6;
+ CONFIG_WATER_VOLUME_MENU=6;
+ CONFIG_WATER_VOLUME_GAME=10;
+ CONFIG_MUSIC_VOLUME=12;
  CONFIG_LEVEL_MAP=0;
  CONFIG_LEVEL_FG=135;
  CONFIG_LEVEL_BG=131;
@@ -303,6 +306,7 @@ static int load_disk_options (void)
 	CONFIG_CLICK_VOLUME=get_config_int(LABEL_MAIN,LABEL_CLICK_VOLUME,CONFIG_CLICK_VOLUME);
 	CONFIG_WATER_VOLUME_MENU=get_config_int(LABEL_MAIN,LABEL_WATER_VOLUME_MENU,CONFIG_WATER_VOLUME_MENU);
 	CONFIG_WATER_VOLUME_GAME=get_config_int(LABEL_MAIN,LABEL_WATER_VOLUME_GAME,CONFIG_WATER_VOLUME_GAME);
+	CONFIG_MUSIC_VOLUME=get_config_int(LABEL_MAIN,LABEL_MUSIC_VOLUME,CONFIG_MUSIC_VOLUME);
 
 	CONFIG_LEVEL_MAP=get_config_int(LABEL_MAIN,LABEL_LEVEL_MAP,CONFIG_LEVEL_MAP);
 	CONFIG_LEVEL_FG=get_config_int(LABEL_MAIN,LABEL_LEVEL_FG,CONFIG_LEVEL_FG);
@@ -392,6 +396,7 @@ int save_config_options (void)
 	set_config_int(LABEL_MAIN,LABEL_CLICK_VOLUME,CONFIG_CLICK_VOLUME);
 	set_config_int(LABEL_MAIN,LABEL_WATER_VOLUME_MENU,CONFIG_WATER_VOLUME_MENU);
 	set_config_int(LABEL_MAIN,LABEL_WATER_VOLUME_GAME,CONFIG_WATER_VOLUME_GAME);
+	set_config_int(LABEL_MAIN,LABEL_MUSIC_VOLUME,CONFIG_MUSIC_VOLUME);
 
 	set_config_int(LABEL_MAIN,LABEL_LEVEL_MAP,CONFIG_LEVEL_MAP);
 	set_config_int(LABEL_MAIN,LABEL_LEVEL_FG,CONFIG_LEVEL_FG);
