@@ -70,11 +70,13 @@
 
 int RAW_TEXTURE_NUMBER=0;
 int RAW_MAP_NUMBER=0;
+int MIDI_MUSIC_NUMBER=0;
 
 int LOADED_BACK=0;
 int LOADED_TEXTURE=0;
 int LOADED_SFX=0;
 int LOADED_WATER=0;
+int LOADED_MUSIC=0;
 
 SAMPLE *SAMPLE_SFX_TIME;
 SAMPLE *SAMPLE_SFX_WIN;
@@ -86,6 +88,7 @@ SAMPLE *SAMPLE_WATER[SAMPLE_WATER_NUMBER];
 void   *RAW_MAP[RAW_MAP_MAX_NUMBER];
 void   *RAW_MAP_ORDERED[RAW_MAP_MAX_NUMBER];
 void   *RAW_TEXTURE[RAW_TEXTURE_MAX_NUMBER];
+MIDI   *MIDI_MUSIC[MIDI_MUSIC_MAX_NUMBER];
 
 BITMAP *BACK_IMAGE;
 
@@ -238,6 +241,19 @@ static void read_help_dat (DATAFILE *df)
     }
 }
 
+/*------------------------------------------------------------------*/
+static void read_music_dat (DATAFILE *df)
+{
+  int i;
+
+  MIDI_MUSIC_NUMBER=0;
+  for (i=0; i<MIDI_MUSIC_DAT_NUMBER && df[i].type!=DAT_END; ++i)
+    {
+      MIDI_MUSIC[i]=df[i].dat;
+      MIDI_MUSIC_NUMBER++;
+    }
+}
+
 /*------------------------------------------------------------------*/
 int load_dat (void)
 {
@@ -318,8 +334,7 @@ int load_dat (void)
 	result&=!STARTUP_CHECK;
       display_success (df!=NULL);
     }
-  if (loadable && STARTUP_TEXTURE_STATE)
-    {
+  if (loadable && STARTUP_TEXTURE_STATE)    {
       log_print_str( "Loading textures");
       log_flush();
       df=load_datafile_object (STARTUP_DAT_PATH,"texture_dat");
@@ -348,6 +363,21 @@ int load_dat (void)
       display_success (df!=NULL);
     }
 
+  if (loadable && STARTUP_MUSIC_STATE)
+    {
+      log_print_str( "Loading midi music");
+      log_flush ();
+      df=load_datafile_object (STARTUP_DAT_PATH,"music_dat");
+      if (df!=NULL)
+	{
+	  read_music_dat (df[0].dat);
+	  LOADED_MUSIC=1;
+	}
+      else
+	result&=!STARTUP_CHECK;
+      display_success (df!=NULL);
+    }
+
   return loadable && result;
 }
 
@@ -417,6 +447,39 @@ static int load_custom_map (void)
   return result;
 }
 
+/*------------------------------------------------------------------*/
+static void load_custom_music_callback(const char *file, int mode, int unused)
+{
+  void *pointeur;
+
+  if ((pointeur=load_midi(file)) !=NULL)
+    {
+      MIDI_MUSIC[MIDI_MUSIC_NUMBER++]=pointeur;
+      log_print_str(".");
+      log_flush();
+    }
+}
+
+/*------------------------------------------------------------------*/
+static int load_custom_music (void)
+{
+  int result=1;
+  char buf[512];
+  int l;
+
+  strcpy(buf,STARTUP_MID_PATH);
+  l=strlen(buf);
+
+#ifdef ALLEGRO_UNIX
+  strcpy(buf+l,"/*");
+#else
+  strcpy(buf+l,"\\*.*");
+#endif
+  for_each_file(buf,FA_RDONLY,load_custom_music_callback,0);
+
+  return result;
+}
+
 /*------------------------------------------------------------------*/
 int load_custom (void)
 {
@@ -446,6 +509,18 @@ int load_custom (void)
       display_success (success);
     }
 
+  if (STARTUP_CUSTOM_STATE && STARTUP_MUSIC_STATE)
+    {
+      log_print_str( "Loading custom musics from \"");
+      log_print_str(STARTUP_MID_PATH);
+      log_print_str("\"");
+      log_flush();
+      success=load_custom_music();
+      if (!success)
+	result&=!STARTUP_CHECK;
+      display_success (success);
+    }
+
   return result;
 }
 
