@@ -69,6 +69,9 @@
 #define RAW_TEXTURE_MAX_NUMBER 1024 
 #define RAW_TEXTURE_DAT_NUMBER  512
 
+#define MIDI_MUSIC_MAX_NUMBER   256
+#define MIDI_MUSIC_DAT_NUMBER     3
+
 #define LANGAGE_NUMBER      2
 #define HELP_TEXT_NUMBER    13
 
@@ -95,6 +98,7 @@
 
 extern int RAW_TEXTURE_NUMBER;
 extern int RAW_MAP_NUMBER;
+extern int MIDI_MUSIC_NUMBER;
 
 extern int LOADED_BACK;
 extern int LOADED_TEXTURE;
@@ -111,6 +115,7 @@ extern SAMPLE *SAMPLE_WATER[SAMPLE_WATER_NUMBER];
 extern void   *RAW_MAP[RAW_MAP_MAX_NUMBER];
 extern void   *RAW_MAP_ORDERED[RAW_MAP_MAX_NUMBER];
 extern void   *RAW_TEXTURE[RAW_TEXTURE_MAX_NUMBER];
+extern MIDI   *MIDI_MUSIC[MIDI_MUSIC_MAX_NUMBER];
 
 extern BITMAP *BACK_IMAGE;
 
