@@ -125,7 +125,9 @@ static void disp_init_fail_message (void)
   log_println_str("Try \"lw -silent\" to disable sound management.");
   log_println_str("Try \"lw -nojoy\" to disable joystick control.");
   log_println();
-  log_println_str("Try to delete your \"lw.cfg\" file and restart Liquid War.");
+  log_print_str("Try to delete the \"");
+  log_print_str(STARTUP_CFG_PATH);
+  log_println_str("\" file and restart Liquid War.");
 }
 
 /*------------------------------------------------------------------*/
@@ -168,7 +170,7 @@ static void disp_mem_trouble_message (void)
 /*------------------------------------------------------------------*/
 static void disp_load_fail_message (void)
 {
-  log_println_str("Liquid War was unable to load your datafile components.");
+  log_println_str("Liquid War was unable to load its datafile.");
   log_println();
   log_print_str("Please first check that \"");
   log_print_str(STARTUP_DAT_PATH);
@@ -247,6 +249,8 @@ void my_exit (int code)
       disp_error_message ();
     }
 
+  log_exit();
+
   exit (code);
 }
 
