@@ -59,6 +59,7 @@
 #include "log.h"
 #include "gfxmode.h"
 #include "startup.h"
+#include "init.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -149,7 +150,6 @@ int set_resolution (int res, int flip, int fullscreen)
     log_print_str(", windowed");
   if (flip)
     log_print_str(", page flipping enabled");
-  log_println_str(".");
 
   nb_try=0;
   while (nb_try<5 && ret){
@@ -198,6 +198,8 @@ int set_resolution (int res, int flip, int fullscreen)
       set_window_title("Liquid War " LW_VERSION);
     }
 
+  display_success_driver(!ret,(char *) gfx_driver->ascii_name);
+
   return (ret);
 }
 
