@@ -74,85 +74,115 @@
 /*------------------------------------------------------------------*/
 void display_success (int success)
 {
- if (success)
-     log_println_str (" - success!");
- else
-   log_println_str (" - failed...");  
-   log_flush();
-/* delay (100);*/
+  if (success)
+    log_println_str (" - success!");
+  else
+    log_println_str (" - failed...");  
+  log_flush();
+  /* delay (100);*/
+}
+
+/*------------------------------------------------------------------*/
+void display_success_driver (int success, char *driver)
+{
+  if (success)
+    {
+      log_print_str(" (driver=\"");
+      log_print_str(driver);
+      log_println_str ("\") - success!");
+    }
+  else
+    log_println_str (" - failed...");  
+  log_flush();
+  /* delay (100);*/
 }
 
 /*------------------------------------------------------------------*/
 int init_all ()
 {
- int result=0;
- int config=1,timer=1,keyboard=1,mouse=1,sound=1,joystick=1,network=1;
+  int result=0;
+  int config=1,timer=1,keyboard=1,mouse=1,sound=1,joystick=1,network=1;
 
- allegro_init ();
- #ifdef ALLEGRO_DOS
- set_gfx_mode (GFX_TEXT, 0, 0, 0, 0);
- #endif
- log_println_str ("Starting Allegro (http://www.talula.demon.co.uk/allegro)");
- log_println();
- log_print_str("Allegro ID : ");
- log_println_str(allegro_id);
- log_println();
+  set_startup();
+
+  log_init();
+
+  allegro_init ();
+#ifdef ALLEGRO_DOS
+  set_gfx_mode (GFX_TEXT, 0, 0, 0, 0);
+#endif
+  log_println_str ("Starting Allegro (http://www.talula.demon.co.uk/allegro)");
+  log_println();
+  log_print_str("Allegro ID : ");
+  log_println_str(allegro_id);
+  log_println();
  
- set_startup();
- log_print_str("Loading config options from \"");
- log_print_str(STARTUP_CFG_PATH);
- log_print_str("\"");
+  log_print_str("Loading config options from \"");
+  log_print_str(STARTUP_CFG_PATH);
+  log_print_str("\"");
  
- display_success (config=load_config_options());
+  display_success (config=load_config_options());
 
- log_print_str("Installing timer");
+  log_print_str("Installing timer");
 
- display_success (timer=!install_timer ());
+  display_success_driver (timer=!install_timer (),
+			  (char *) timer_driver->ascii_name);
 
- start_ticker();
+  start_ticker();
 
- log_print_str ("Installing keyboard");
- display_success (keyboard=!install_keyboard ());
+  log_print_str ("Installing keyboard");
+  display_success_driver (keyboard=!install_keyboard (),
+			  (char *) keyboard_driver->ascii_name);
 
- log_print_str ("Installing mouse");
- display_success (mouse=install_mouse () != -1);
+  log_print_str ("Installing mouse");
+  display_success_driver (mouse=install_mouse () != -1,
+			  (char *) mouse_driver->ascii_name);
 
- if (STARTUP_DIGI_CARD != DIGI_NONE)
-     {
-     log_print_str ("Installing sound");
-     display_success (sound=!install_sound
-                     (STARTUP_DIGI_CARD,
-                     MIDI_NONE,
-                     ""));
-     }
- if (STARTUP_JOYSTICK_ON)
+  if (STARTUP_DIGI_CARD != DIGI_NONE || STARTUP_MIDI_CARD != MIDI_NONE)
     {
-     log_print_str ("Installing joystick");
-     if (STARTUP_JOYSTICK_ON)
-        display_success (joystick=!my_initialise_joystick ());
+      log_print_str ("Installing sound");
+      sound=!install_sound(STARTUP_DIGI_CARD,STARTUP_MIDI_CARD,"");
+      if (sound) 
+	{
+	  log_print_str(" (digi=\"");
+	  log_print_str((char *) digi_driver->ascii_name);
+	  log_print_str("\", midi=\"");
+	  log_print_str((char *) midi_driver->ascii_name);
+	  log_print_str("\")");
+	} 
+      display_success(sound);
     }
 
- log_print_str("Setting up network");
- display_success(network=lw_sock_init());
+  if (STARTUP_JOYSTICK_ON)
+    {
+      log_print_str ("Installing joystick");
+      if (STARTUP_JOYSTICK_ON)
+	display_success_driver (joystick=!my_initialise_joystick (),
+				(char *) joystick_driver->ascii_name);
+    }
 
- set_color_conversion (COLORCONV_TOTAL);
+  log_print_str("Setting up network");
+  display_success(network=lw_sock_init());
 
- result= timer&&keyboard&&mouse
-         &&(sound||!STARTUP_CHECK)
-         &&(joystick||!STARTUP_CHECK);
+  set_color_conversion (COLORCONV_TOTAL);
+  
+  result= timer&&keyboard&&mouse
+    &&(sound||!STARTUP_CHECK)
+    &&(joystick||!STARTUP_CHECK);
 
- return (result);
+  return (result);
 }
 
 /*------------------------------------------------------------------*/
 int start_graphic (void)
 {
- int retour;
+  int retour;
 
- retour= (!set_resolution (CONFIG_GFX_MENU,0,CONFIG_FULLSCREEN));
+  retour= (!set_resolution (CONFIG_GFX_MENU,0,CONFIG_FULLSCREEN));
 
- return retour;
+  return retour;
 }
 
 
 
+  
