@@ -56,12 +56,17 @@
 #include <stdlib.h>
 #include <stdio.h>
 
+#include "startup.h"
 #include "log.h"
 
 /*==================================================================*/
 /* definitions de types                                             */
 /*==================================================================*/
 
+#ifndef ALLEGRO_UNIX
+FILE *lw_log_file=NULL;
+#endif;
+
 /*==================================================================*/
 /* variables globales                                               */
 /*==================================================================*/
@@ -70,45 +75,99 @@
 /* fonctions                                                        */
 /*==================================================================*/
 
+
+/*------------------------------------------------------------------*/
+void log_init(void) {
+#ifndef ALLEGRO_UNIX
+  lw_log_file=fopen(STARTUP_LOG_PATH,"w");
+#endif  
+}
+
+/*------------------------------------------------------------------*/
+void log_exit(void) {
+#ifndef ALLEGRO_UNIX
+  if (lw_log_file)
+    {
+      fclose(lw_log_file);
+    }
+#endif  
+}
+
 /*------------------------------------------------------------------*/
 void log_print_str(char *str){
-	#ifndef ALLEGRO_WINDOWS
-	printf("%s",str);
-	#endif
+#ifndef ALLEGRO_WINDOWS
+  printf("%s",str);
+#endif
+#ifndef ALLEGRO_UNIX
+  if (lw_log_file) 
+    {
+      fprintf(lw_log_file,"%s",str);
+    }
+#endif  
 }
 
 /*------------------------------------------------------------------*/
 void log_print_int(int i){
-	#ifndef ALLEGRO_WINDOWS
-	printf("%d",i);
-	#endif
+#ifndef ALLEGRO_WINDOWS
+  printf("%d",i);
+#endif
+#ifndef ALLEGRO_UNIX
+  if (lw_log_file) 
+    {
+      fprintf(lw_log_file,"%d",i);
+    }
+#endif  
 }
 
 /*------------------------------------------------------------------*/
 void log_println(){
-	#ifndef ALLEGRO_WINDOWS
-	printf("\n");
-	#endif
+#ifndef ALLEGRO_WINDOWS
+  printf("\n");
+#endif
+#ifndef ALLEGRO_UNIX
+  if (lw_log_file) 
+    {
+      fprintf(lw_log_file,"\n");
+    }
+#endif  
 }
 
 /*------------------------------------------------------------------*/
 void log_println_str(char *str){
-	#ifndef ALLEGRO_WINDOWS
-	printf("%s\n",str);
-	#endif
+#ifndef ALLEGRO_WINDOWS
+  printf("%s\n",str);
+#endif
+#ifndef ALLEGRO_UNIX
+  if (lw_log_file) 
+    {
+      fprintf(lw_log_file,"%s\n",str);
+    }
+#endif  
 }
 
 /*------------------------------------------------------------------*/
 void log_println_int(int i){
-	#ifndef ALLEGRO_WINDOWS
-	printf("%d\n",i);
-	#endif
+#ifndef ALLEGRO_WINDOWS
+  printf("%d\n",i);
+#endif
+#ifndef ALLEGRO_UNIX
+  if (lw_log_file) 
+    {
+      fprintf(lw_log_file,"%d\n",i);
+    }
+#endif  
 }
 
 /*------------------------------------------------------------------*/
 void log_flush(){
-	#ifndef ALLEGRO_WINDOWS
-	fflush(stdout);
-	#endif
+#ifndef ALLEGRO_WINDOWS
+  fflush(stdout);
+#endif
+#ifndef ALLEGRO_UNIX
+  if (lw_log_file) 
+    {
+      fflush(lw_log_file);
+    }
+#endif  
 }
 
