@@ -69,6 +69,16 @@
 /* fonctions                                                        */
 /*==================================================================*/
 
+/*------------------------------------------------------------------*/
+void log_init(void) {
+
+}
+
+/*------------------------------------------------------------------*/
+void log_exit(void) {
+
+}
+
 /*------------------------------------------------------------------*/
 void log_print_str(char *str){
   	printf("%s",str);
