@@ -67,6 +67,7 @@
 #include "sound.h"
 #include "sock2gen.h"
 #include "keyexch.h"
+#include "music.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -170,10 +171,20 @@ int play_sequence (void)
        */
       my_fade_in ();
 
+      /*
+       * start playing some music
+       */
+      start_music();
+
       /*
        * OK, here we go, let's enter the main game loop
        */
       game ();
+
+      /*
+       * stop the music
+       */
+      stop_music();
      }
 
      /*
