@@ -66,8 +66,9 @@ int WATER_VOLUME=0;
 static int HASARD_VALUE[HASARD_SIZE];
 static int HASARD_INDEX;
 
-static int SOUND_VOLUME_VALUES[16]=
-       { 8,10,13,16,
+static int SOUND_VOLUME_VALUES[17]=
+       { 0,
+	 8,10,13,16,
          20,25,32,40,
          51,64,81,101,
          128,161,204,255};
@@ -100,7 +101,7 @@ static void water_handler (void)
 
      hasard=HASARD_VALUE[HASARD_INDEX]%SAMPLE_WATER_NUMBER;
      play_sample (SAMPLE_WATER [hasard],
-                 SOUND_VOLUME_VALUES[WATER_VOLUME-1],
+                 SOUND_VOLUME_VALUES[WATER_VOLUME],
                  pan, 1000, 0);
     }
 }
@@ -128,7 +129,7 @@ int start_water (void)
 
 	#ifdef ALLEGRO_DOS
      _go32_dpmi_lock_data (HASARD_VALUE,HASARD_SIZE*sizeof(int));
-     _go32_dpmi_lock_data (SOUND_VOLUME_VALUES,16*sizeof(int));
+     _go32_dpmi_lock_data (SOUND_VOLUME_VALUES,17*sizeof(int));
 	#endif
 
      result=install_int_ex (water_handler,
