@@ -68,6 +68,7 @@
 #define IDENT_NOTEXTURE           "notex"
 #define IDENT_NOWATER             "nowater"
 #define IDENT_NOSFX               "nosfx"
+#define IDENT_NOMUSIC             "nomusic"
 #define IDENT_NOCUSTOM            "nocustom"
 #define IDENT_NOSOUND             "silent"
 #define IDENT_NOSVGA              "vga"
@@ -82,6 +83,7 @@
 #define IDENT_DAT                 "dat"
 #define IDENT_MAP                 "map"
 #define IDENT_TEX                 "tex"
+#define IDENT_MID                 "mid"
 
 #define STARTUP_MAX_PATH_LENGTH           1000
 
@@ -91,11 +93,13 @@ int STARTUP_BIG_DATA=8192;
 int STARTUP_BIG_DATA=16384;
 #endif
 int STARTUP_DIGI_CARD=DIGI_AUTODETECT;
+int STARTUP_MIDI_CARD=MIDI_AUTODETECT;
 int STARTUP_JOYSTICK_ON=1;
 int STARTUP_BACK_STATE=1;
 int STARTUP_TEXTURE_STATE=1;
 int STARTUP_WATER_STATE=1;
 int STARTUP_SFX_STATE=1;
+int STARTUP_MUSIC_STATE=1;
 int STARTUP_CUSTOM_STATE=1;
 int STARTUP_ASM=1;
 int STARTUP_SVGA=1;
@@ -106,19 +110,25 @@ int STARTUP_CHECK=0;
 #ifdef ALLEGRO_UNIX
   static char *DEFAULT_CFG_PATH=CONFIG_UNIX_CFG;
   static char *DEFAULT_DAT_PATH=CONFIG_UNIX_DAT;
+  static char *DEFAULT_LOG_PATH="";
   static char *DEFAULT_MAP_PATH=CONFIG_UNIX_MAP;
   static char *DEFAULT_TEX_PATH=CONFIG_UNIX_TEX;
+  static char *DEFAULT_MID_PATH=CONFIG_UNIX_MID;
 #else
   static char *DEFAULT_CFG_PATH="data/lw.cfg";
   static char *DEFAULT_DAT_PATH="data/lw.dat";
+  static char *DEFAULT_LOG_PATH="data/lw.log";
   static char *DEFAULT_MAP_PATH="custom/map/";
   static char *DEFAULT_TEX_PATH="custom/texture/";
+  static char *DEFAULT_MID_PATH="custom/music/";
 #endif
 
 char STARTUP_CFG_PATH[STARTUP_MAX_PATH_LENGTH];
 char STARTUP_DAT_PATH[STARTUP_MAX_PATH_LENGTH];
+char STARTUP_LOG_PATH[STARTUP_MAX_PATH_LENGTH];
 char STARTUP_MAP_PATH[STARTUP_MAX_PATH_LENGTH];
 char STARTUP_TEX_PATH[STARTUP_MAX_PATH_LENGTH];
+char STARTUP_MID_PATH[STARTUP_MAX_PATH_LENGTH];
 
 /*==================================================================*/
 /* fonctions                                                        */
@@ -167,6 +177,13 @@ static void set_load_states (void)
     && exist_argument (IDENT_NOWATER)))
     STARTUP_DIGI_CARD=DIGI_NONE;
 
+ if (exist_argument (IDENT_NOMUSIC)
+     || ( exist_argument (IDENT_NOSOUND)))
+   {
+     STARTUP_MUSIC_STATE=0;
+     STARTUP_MIDI_CARD=MIDI_NONE;
+   }
+ 
  if (exist_argument (IDENT_NOCUSTOM))
     STARTUP_CUSTOM_STATE=0;
 }
@@ -226,6 +243,7 @@ static void set_safe (void)
      STARTUP_TEXTURE_STATE=0;
      STARTUP_WATER_STATE=0;
      STARTUP_SFX_STATE=0;
+     STARTUP_MUSIC_STATE=0;
      STARTUP_CUSTOM_STATE=0;
      STARTUP_SVGA=0;
     }
@@ -270,6 +288,8 @@ static void set_path (void)
      strcat(STARTUP_CFG_PATH,DEFAULT_CFG_PATH);
     }
 
+ strcpy(STARTUP_LOG_PATH,DEFAULT_LOG_PATH);
+
  if (exist_argument_value (IDENT_DAT))
      strcpy(STARTUP_DAT_PATH,get_argument_str (IDENT_DAT));
  else
@@ -285,9 +305,15 @@ static void set_path (void)
  else
      strcpy(STARTUP_MAP_PATH,DEFAULT_MAP_PATH);
 
+ if (exist_argument_value (IDENT_MID))
+     strcpy(STARTUP_MID_PATH,get_argument_str (IDENT_MID));
+ else
+     strcpy(STARTUP_MID_PATH,DEFAULT_MID_PATH);
+
 
  correct_path (STARTUP_TEX_PATH);
  correct_path (STARTUP_MAP_PATH);
+ correct_path (STARTUP_MID_PATH);
 }
 
 /*------------------------------------------------------------------*/
