@@ -61,11 +61,13 @@
 
 extern int STARTUP_BIG_DATA;
 extern int STARTUP_DIGI_CARD;
+extern int STARTUP_MIDI_CARD;
 extern int STARTUP_JOYSTICK_ON;
 extern int STARTUP_BACK_STATE;
 extern int STARTUP_TEXTURE_STATE;
 extern int STARTUP_WATER_STATE;
 extern int STARTUP_SFX_STATE;
+extern int STARTUP_MUSIC_STATE;
 extern int STARTUP_CUSTOM_STATE;
 extern int STARTUP_ASM;
 extern int STARTUP_SVGA;
@@ -75,8 +77,10 @@ extern int STARTUP_CHECK;
 
 extern char STARTUP_CFG_PATH[];
 extern char STARTUP_DAT_PATH[];
+extern char STARTUP_LOG_PATH[];
 extern char STARTUP_MAP_PATH[];
 extern char STARTUP_TEX_PATH[];
+extern char STARTUP_MID_PATH[];
 
 /*==================================================================*/
 /* variables globales                                               */
