@@ -73,19 +73,19 @@
 int sound_options (void)
 {
   int *temp;
-  DIALOG d[13];
+  DIALOG d[15];
   int i,choix=4,retour=0;
-  static int y_pos[4]={0,2,4,5};
+  static int y_pos[5]={0,2,4,5,7};
 
-  for (i=0; i<4; ++i)
+  for (i=0; i<5; ++i)
       {
-       standard_button (d+i+4,0,y_pos[i],2,6);
+       standard_button (d+i+4,0,y_pos[i],2,8);
        d[i+4].proc=my_textbox_proc;
       }
-  for (i=0; i<4; ++i)
+  for (i=0; i<5; ++i)
       {
-       standard_button (d+i+8,1,y_pos[i],2,6);
-       d[i+8].proc=my_slider_proc;
+       standard_button (d+i+9,1,y_pos[i],2,8);
+       d[i+9].proc=my_slider_proc;
       }
 
   quick_buttons(d);
@@ -94,11 +94,13 @@ int sound_options (void)
   d[5].dp="Click";
   d[6].dp="Game water";
   d[7].dp="Menu water";
-  d[8].dp3=&CONFIG_SFX_VOLUME;
-  d[9].dp3=&CONFIG_CLICK_VOLUME;
-  d[10].dp3=&CONFIG_WATER_VOLUME_GAME;
-  d[11].dp3=&WATER_VOLUME;
-  for (i=8;i<12;++i)
+  d[8].dp="Music";
+  d[9].dp3=&CONFIG_SFX_VOLUME;
+  d[10].dp3=&CONFIG_CLICK_VOLUME;
+  d[11].dp3=&CONFIG_WATER_VOLUME_GAME;
+  d[12].dp3=&WATER_VOLUME;
+  d[13].dp3=&CONFIG_MUSIC_VOLUME;
+  for (i=9;i<14;++i)
       {
        d[i].d1=16;
        d[i].dp=NULL;
@@ -107,7 +109,7 @@ int sound_options (void)
        d[i].d2=*temp;
       }
  
-  d[12].proc=0;
+  d[14].proc=0;
 
   while (retour==0)
         {
