@@ -354,7 +354,11 @@ int main (int argc, char **argv)
  ARGC=argc;
  ARGV=argv;
 
+#ifdef ALLEGRO_UNIX
+ install_allegro(SYSTEM_NONE, &errno, atexit);
+#else
  allegro_init ();
+#endif
 
  if (read_command_line ())
     {
