@@ -236,7 +236,7 @@ void convert_to_buffer (void)
    l=0;
    if (!data[pos_src])
       {
-       while ((!data[pos_src]) && pos_src<wh && l<127)
+       while (pos_src<wh && (!data[pos_src]) && l<127)
          {
           l++;
           pos_src++;
@@ -245,7 +245,7 @@ void convert_to_buffer (void)
       }
    else
       {
-       while (data[pos_src] && pos_src<wh && l<127)
+       while (pos_src<wh && data[pos_src] && l<127)
          {
           l++;
           pos_src++;
